#include <QtGui>

#include "auDlg.h"
#include "Document.h"
#include "AUMove.h"
#include "Wfm.h"

#define MAX_SCALE_AU 150
#define MIN_SCALE_AU 0
#define UNIT_AU 0.01

AuDlg::AuDlg(EditGLDlg *editGLDlg, QWidget *parent)
	: QDialog(parent)
{
	m_pEditGLDlg = editGLDlg;

	for( int num = 0; num < AU_SLIDER_NUM; num++ ) {
		m_pLabel[num] = new QLabel(tr(AU_SLIDER_NAME[num]));
		m_pLabel[num]->setAlignment(Qt::AlignRight);
		m_pSpin[num] = new QSpinBox;
		m_pSpin[num]->setRange(MIN_SCALE_AU, MAX_SCALE_AU);
		m_pSlider[num] = new QSlider(Qt::Horizontal);
		m_pSlider[num]->setRange(MIN_SCALE_AU, MAX_SCALE_AU);
			
		QObject::connect(m_pSpin[num], SIGNAL(valueChanged(int)),
						 m_pSlider[num], SLOT(setValue(int)));
		QObject::connect(m_pSlider[num], SIGNAL(valueChanged(int)),
						 m_pSpin[num], SLOT(setValue(int)));
		QObject::connect(m_pSpin[num], SIGNAL(valueChanged(int)),
						 this, SLOT(AuChange()));
		m_pSpin[num]->setValue(MIN_SCALE_AU);
	}
	m_pResetButton = new QPushButton(tr("All Reset"));
	QObject::connect(m_pResetButton, SIGNAL(clicked()),
					 this, SLOT(AllReset()));

	QGridLayout *layout = new QGridLayout;
	layout->setSpacing(1);

	int num;
	for( num = 0; num < AU_SLIDER_NUM; num++ ) {
		layout->addWidget(m_pLabel[num], (num - num % 2) / 2, 0 + 4 * (num % 2));
		layout->addWidget(m_pSpin[num],  (num - num % 2) / 2, 1 + 4 * (num % 2));
		layout->addWidget(m_pSlider[num],(num - num % 2) / 2, 2 + 4 * (num % 2));
	}	
    layout->addWidget(m_pResetButton,(num - num % 2) / 2, 2 + 4 * (num % 2));

	setLayout(layout);
	
	setWindowTitle(tr("AU Controller"));
}
void AuDlg::AuChange()
{
	float dAUMove[AU_SLIDER_NUM];
	Wfm *workWfm = m_pEditGLDlg->GetDocument()->GetWorkWfm();
	Wfm *tempWfm = m_pEditGLDlg->GetDocument()->GetTempWfm();
	AUMove *pAUMove = m_pEditGLDlg->GetDocument()->GetAUMove();
	
	for( int i = 0; i < AU_SLIDER_NUM; i++ ) {
		dAUMove[i] = m_pSpin[i]->value() * UNIT_AU;
	}
	
	pAUMove->setWfm(workWfm, tempWfm);
	pAUMove->resetWfm();
	pAUMove->auMove(dAUMove);
	m_pEditGLDlg->redraw_window();
}

void AuDlg::AllReset()
{
	for( int num = 0; num < AU_SLIDER_NUM; num++ ) {
		m_pSpin[num]->setValue(MIN_SCALE_AU);
	}
	AuChange();
}

bool AuDlg::SaveUserAU(const char *filename)
{
	Wfm *workWfm = m_pEditGLDlg->GetDocument()->GetWorkWfm();
	Wfm	*wfm_temp = m_pEditGLDlg->GetDocument()->GetTempWfm();
	
	workWfm->saveDiff(filename, wfm_temp);
	return true;
}

bool AuDlg::OpenUserAU(const char *filename)
{
	AUMove *pAUMove = m_pEditGLDlg->GetDocument()->GetAUMove();
	return pAUMove->openUserDefAUData(filename);
}

const char *AuDlg::AU_SLIDER_NAME[] = 
{  
	"AU01",
	"AU02",
	"AU04",
	"AU05",
	"AU06",
	"AU07",
	"AU09",
	"AU10",
	"AU11",
	"AU12",
	"AU13",
	"AU14",
	"AU15",
	"AU16",
	"AU17",
	"AU18",
	"AU20",
	"AU22",
	"AU23",
	"AU24",
	"AU25",
	"AU26",
	"AU27",
	"AU28",
	"AU29",
	"AU30",
	"AU35",
	"AU41",
	"AU42",
	"AU43",
	"Happiness",
	"Anger",
	"Disgust",
	"Sadness",
	"Surprise",
	"Fear",
	"User Def",
	NULL
};


