#include <QtGui>

#include "eyeDlg.h"
#include "ObjModel.h"

#define MAX_ROTATE_EYE 300
#define MIN_ROTATE_EYE -300
#define DEF_ROTATE_EYE 0
#define UNIT_ROTATE_EYE 0.1

#define MAX_TRANS_EYE 100
#define MIN_TRANS_EYE -100
#define DEF_TRANS_EYE 0
#define UNIT_TRANS_EYE 0.001

#define MAX_SCALE_EYE 150
#define MIN_SCALE_EYE 1
#define DEF_SCALE_EYE 100
#define UNIT_SCALE_EYE 0.01


EyeDlg::EyeDlg(EditGLDlg *editGLDlg, QWidget *parent)
	: QDialog(parent)
{
	m_pEditGLDlg = editGLDlg;

	
	for( int num = 0; num < EYE_SLIDER_NUM; num++ ) {
		m_pLabel[num] = new QLabel(tr(EYE_SLIDER_NAME[num]));
		m_pLabel[num]->setAlignment(Qt::AlignRight);
		m_pSlider[num] = new QSlider(Qt::Horizontal);
		
		QObject::connect(m_pSlider[num], SIGNAL(valueChanged(int)),
						 this, SLOT(EyeChange()));
	}
	
	m_pSlider[EYE_SLIDER_TRANS_Z_LEFT]->setRange(MIN_TRANS_EYE, MAX_TRANS_EYE);
	m_pSlider[EYE_SLIDER_TRANS_Z_LEFT]->setValue(DEF_TRANS_EYE);
	m_pSlider[EYE_SLIDER_TRANS_Z_RIGHT]->setRange(MIN_TRANS_EYE, MAX_TRANS_EYE);
	m_pSlider[EYE_SLIDER_TRANS_Z_RIGHT]->setValue(DEF_TRANS_EYE);	
	m_pSlider[EYE_SLIDER_ROT_X_LEFT]->setRange(MIN_ROTATE_EYE, MAX_ROTATE_EYE);
	m_pSlider[EYE_SLIDER_ROT_X_LEFT]->setValue(DEF_ROTATE_EYE);	
	m_pSlider[EYE_SLIDER_ROT_X_RIGHT]->setRange(MIN_ROTATE_EYE, MAX_ROTATE_EYE);
	m_pSlider[EYE_SLIDER_ROT_X_RIGHT]->setValue(DEF_ROTATE_EYE);	
	m_pSlider[EYE_SLIDER_ROT_Y_LEFT]->setRange(MIN_ROTATE_EYE, MAX_ROTATE_EYE);
	m_pSlider[EYE_SLIDER_ROT_Y_LEFT]->setValue(DEF_ROTATE_EYE);	
	m_pSlider[EYE_SLIDER_ROT_Y_RIGHT]->setRange(MIN_ROTATE_EYE, MAX_ROTATE_EYE);
	m_pSlider[EYE_SLIDER_ROT_Y_RIGHT]->setValue(DEF_ROTATE_EYE);	
	m_pSlider[EYE_SLIDER_SCALE]->setRange(MIN_SCALE_EYE, MAX_SCALE_EYE);
	m_pSlider[EYE_SLIDER_SCALE]->setValue(DEF_SCALE_EYE);	
	
	QGridLayout *layout = new QGridLayout;
	layout->setSpacing(1);

	int num;
	for( num = 0; num < EYE_SLIDER_NUM; num++ ) {
		layout->addWidget(m_pLabel[num], num, 0);
		layout->addWidget(m_pSlider[num], num, 1);
	}
	setLayout(layout);
	
	setWindowTitle(tr("Eye Position Controller"));
}

void EyeDlg::SetTransSliderValue(int num, float value) 
{ 
	m_pSlider[num]->setValue(int(value / UNIT_TRANS_EYE)); 
}
void EyeDlg::SetScaleSliderValue(int num, float value) 
{ 
	m_pSlider[num]->setValue(int(value / UNIT_SCALE_EYE)); 
}
void EyeDlg::SetRotateSliderValue(int num, float value) 
{ 
	m_pSlider[num]->setValue(int(value / UNIT_ROTATE_EYE)); 
}

void EyeDlg::EyeChange()
{
	double *dEyeRTransValue = m_pEditGLDlg->GetDocument()->GetEyeRLocalTrans();
	double *dEyeLTransValue = m_pEditGLDlg->GetDocument()->GetEyeLLocalTrans();
	double *dEyeRRotValue = m_pEditGLDlg->GetDocument()->GetEyeRLocalRot();
	double *dEyeLRotValue = m_pEditGLDlg->GetDocument()->GetEyeLLocalRot();
	double &dScaleEyeValue = m_pEditGLDlg->GetDocument()->GetEyeTexScale();
	ObjModel *obj = m_pEditGLDlg->GetDocument()->GetEyeObject();
	
	dEyeLTransValue[2] = m_pSlider[EYE_SLIDER_TRANS_Z_LEFT]->value() * UNIT_TRANS_EYE;
	dEyeRTransValue[2] = m_pSlider[EYE_SLIDER_TRANS_Z_RIGHT]->value() * UNIT_TRANS_EYE;
	dEyeLRotValue[0] = m_pSlider[EYE_SLIDER_ROT_X_LEFT]->value() * UNIT_ROTATE_EYE;
	dEyeRRotValue[0] = m_pSlider[EYE_SLIDER_ROT_X_RIGHT]->value() * UNIT_ROTATE_EYE;
	dEyeLRotValue[1] = m_pSlider[EYE_SLIDER_ROT_Y_LEFT]->value() * UNIT_ROTATE_EYE;
	dEyeRRotValue[1] = m_pSlider[EYE_SLIDER_ROT_Y_RIGHT]->value() * UNIT_ROTATE_EYE;
	dScaleEyeValue = m_pSlider[EYE_SLIDER_SCALE]->value() * UNIT_SCALE_EYE;
	
	obj->ReCalcTexture(dScaleEyeValue);
	
	m_pEditGLDlg->redraw_window();
}

const char *EyeDlg::EYE_SLIDER_NAME[] = {
	"Trans - Z axis LEFT",
	"Trans - Z axis RIGHT",
	"Rot - X axis LEFT",
	"Rot - X axis RIGHT",
	"Rot - Y axis LEFT",
	"Rot - Y axis RIGHT",
	"Scale - Pupil",
};
