#include <QtGui>
#include <QtOpenGL>

#include <iostream>

#include <math.h>

#include "gleditwidget.h"

using namespace std;

GLEditWidget::GLEditWidget(Document *pDocument, DialogEdit *pView, QWidget *parent)
    : QGLWidget(parent)
{
	m_pDocument = pDocument;
	m_pView = pView;
	m_KeyState = DialogEdit::ACTIVE_NON;
}

GLEditWidget::~GLEditWidget()
{
	makeCurrent();
}

void GLEditWidget::initializeGL()
{
	m_pView->setSize(this->width(), this->height());
}

void GLEditWidget::paintGL()
{
	// redraw
	m_pView->redraw();
}

void GLEditWidget::resizeGL(int width, int height)
{
	m_pView->setSize(width, height);
	updateGL();
}

void GLEditWidget::keyPressEvent(QKeyEvent *event)
{
	if(event->key() == Qt::Key_Control) {
//		cout << "CTRL" << endl;
		m_KeyState = DialogEdit::ACTIVE_CONTROL;
	}
	else if( event->key() == Qt::Key_Shift) {
//		cout << "SHIFT" << endl;
		m_KeyState = DialogEdit::ACTIVE_SHIFT;
	}
	else {
		m_KeyState = DialogEdit::ACTIVE_NON;
//		cout << "OTHER" << endl;
	}
	QGLWidget::keyPressEvent(event);
}
void GLEditWidget::keyReleaseEvent(QKeyEvent *event)
{
	m_KeyState = DialogEdit::ACTIVE_NON;
}

void GLEditWidget::mousePressEvent(QMouseEvent *event)
{
	if(event->button() == Qt::LeftButton) {
		m_pView->LeftMousePushEvent(event->x(), event->y(), m_KeyState);
	}
	else if(event->button() == Qt::RightButton) {
		m_pView->RightMousePushEvent(event->x(), event->y(), m_KeyState);
	}
}

void GLEditWidget::mouseReleaseEvent(QMouseEvent *event)
{
	if(event->button() == Qt::LeftButton) {
		m_pView->LeftMouseReleaseEvent(event->x(), event->y(), m_KeyState);
	}
	else if(event->button() == Qt::RightButton) {
		m_pView->RightMouseReleaseEvent(event->x(), event->y(), m_KeyState);
	}
}

void GLEditWidget::mouseMoveEvent(QMouseEvent *event)
{
//	std::cout <<  event->x() << " " <<  event->y() << std::endl;
	m_pView->MouseDragEvent(event->x(), event->y(), m_KeyState);
	
	updateGL();
}


