#include <QtGui>
#include <QtOpenGL>

#include <iostream>

#include <math.h>

#include "glwidget.h"

using namespace std;

GLWidget::GLWidget(EditGLDlg *editGLDlg, Document *pDocument, View *pView, QWidget *parent)
    : QGLWidget(parent)
{
	m_pDocument = pDocument;
	m_pView = pView;
	m_pEditGLDlg = editGLDlg;
	m_KeyState = View::ACTIVE_NON;
}

GLWidget::~GLWidget()
{
	makeCurrent();
}

void GLWidget::initializeGL()
{
	m_pView->setSize(this->width(), this->height());
}

void GLWidget::paintGL()
{
	// redraw
	m_pView->redraw();
}

void GLWidget::resizeGL(int width, int height)
{
	m_pView->setSize(width, height);
	updateGL();
}

void GLWidget::keyPressEvent(QKeyEvent *event)
{
	if(event->key() == Qt::Key_Control) {
//		cout << "CTRL" << endl;
		m_KeyState = View::ACTIVE_CONTROL;
	}
	else if( event->key() == Qt::Key_Shift) {
//		cout << "SHIFT" << endl;
		m_KeyState = View::ACTIVE_SHIFT;
	}
	else {
		m_KeyState = View::ACTIVE_NON;
//		cout << "OTHER" << endl;
	}
	QGLWidget::keyPressEvent(event);
}
void GLWidget::keyReleaseEvent(QKeyEvent *event)
{
	m_KeyState = View::ACTIVE_NON;
}

void GLWidget::mousePressEvent(QMouseEvent *event)
{
	if(event->button() == Qt::LeftButton) {
		m_pView->LeftMousePushEvent(event->x(), event->y(), m_KeyState);
	}
	else if(event->button() == Qt::RightButton) {
		m_pView->RightMousePushEvent(event->x(), event->y(), m_KeyState);
	}
}

void GLWidget::mouseReleaseEvent(QMouseEvent *event)
{
	if(event->button() == Qt::LeftButton) {
		m_pView->LeftMouseReleaseEvent(event->x(), event->y(), m_KeyState);
	}
	else if(event->button() == Qt::RightButton) {
		m_pView->RightMouseReleaseEvent(event->x(), event->y(), m_KeyState);
	}
	m_pEditGLDlg->redraw_window();
}

void GLWidget::mouseMoveEvent(QMouseEvent *event)
{
//	std::cout <<  event->x() << " " <<  event->y() << std::endl;
	m_pView->MouseDragEvent(event->x(), event->y(), m_KeyState);
	
	updateGL();
	m_pEditGLDlg->redraw_window();
}

