#include <QtGui>
#include <QtOpenGL>

#include "glwidget.h"
#include "auDlg.h"
#include "eyeDlg.h"
#include "teethDlg.h"
#include "editGLDlg.h"

#include "Wfm.h"
#include "ObjModel.h"
#include "Document.h"
#include "View.h"
#include "DialogEdit.h"
#include "TransFace.h"
#include "Texture.h"
#include "mainwindow.h"

#define VERSIONINFO "<h2>FaceMaker V1.0 beta</h2><p>Copyright &copy; 2006 Tatsuo Yotsukura, ATR"

MainWindow::MainWindow()
{
	// window size
	m_main_window_size[0] = MAIN_WIDTH;
	m_main_window_size[1] = MAIN_HEIGHT;
	m_edit_window_size[0] = EDITOR_WIDTH;
	m_edit_window_size[1] = EDITOR_HEIGHT;

	// Create Document object
	m_pDocument = new Document(DEFAULT_PNT_FILE, DEFAULT_LNK_FILE, DEFAULT_EYE_FILE,
							   DEFAULT_MOUTHWALL_FILE, DEFAULT_MOUTHEALL_IMAGE_FILE,
							   DEFAULT_TEETH_U_FILE, DEFAULT_TEETH_L_FILE,
							   DEFAULT_AU_DIR, AuDlg::AU_SLIDER_NUM);
	// Create View object
	m_pView = new View(m_pDocument, &m_main_window_size[0], &m_main_window_size[1]);
	// Create ViewEdit object
	m_pDialogEdit = new DialogEdit(m_pDocument, &m_edit_window_size[0], &m_edit_window_size[1]);

    centralWidget = new QWidget;
    setCentralWidget(centralWidget);
	editGLDlg = new EditGLDlg(m_pDocument, m_pDialogEdit);

	auDlg = new AuDlg(editGLDlg);
	eyeDlg = new EyeDlg(editGLDlg);
	teethDlg = new TeethDlg(editGLDlg);
	
	glWidget = new GLWidget(editGLDlg, m_pDocument, m_pView);
	glWidget->setFocusPolicy(Qt::StrongFocus);
	
	glWidgetArea = new QScrollArea;
    glWidgetArea->setWidget(glWidget);
    glWidgetArea->setWidgetResizable(true);
    glWidgetArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
    glWidgetArea->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
    glWidgetArea->setSizePolicy(QSizePolicy::Ignored, QSizePolicy::Ignored);
    glWidgetArea->setMinimumSize(200, 200);

    createActions();
    createMenus();

	QGridLayout *centralLayout = new QGridLayout;
    centralLayout->addWidget(glWidgetArea, 0, 0);
	
	centralWidget->setLayout(centralLayout);

    setWindowTitle(tr("FaceMaker"));
    resize(m_main_window_size[0], m_main_window_size[1]);
	ButtonStatusNewImage();
}

void MainWindow::createActions()
{
	// Filej[FANVARlNV
	for( int num = 0; num < FILE_B_NUM; num++ ) {
		fileMenuAct[num] = new QAction(FILE_SUBMENU_NAME[num], this);
	}
	connect(fileMenuAct[FILE_NEW_EDIT_B], SIGNAL(triggered()), this, SLOT( clear_file_cb()));
	connect(fileMenuAct[FILE_OPEN_FACE_IMAGE_B], SIGNAL(triggered()), 	this, SLOT( open_face_cb()));
	connect(fileMenuAct[FILE_OPEN_PNT_B], SIGNAL(triggered()), 	this, SLOT( open_pnt_cb()));
	connect(fileMenuAct[FILE_SAVE_PNT_B], SIGNAL(triggered()), this, SLOT( save_pnt_cb()));
	connect(fileMenuAct[FILE_OPEN_EYE_TEX], SIGNAL(triggered()), 	this, SLOT( eye_tex_open_cb()));
	connect(fileMenuAct[FILE_OPEN_EYE_B], SIGNAL(triggered()), this, SLOT( eye_open_cb()));
	connect(fileMenuAct[FILE_SAVE_EYE_B], SIGNAL(triggered()), this, SLOT( eye_save_cb()));
	connect(fileMenuAct[FILE_OPEN_TEETH_B], SIGNAL(triggered()), this, SLOT( teeth_open_cb()));
	connect(fileMenuAct[FILE_SAVE_TEETH_B], SIGNAL(triggered()), this, SLOT( teeth_save_cb()));	
	connect(fileMenuAct[FILE_OPEN_AU_B], SIGNAL(triggered()), this, SLOT( au_open_cb()));
	connect(fileMenuAct[FILE_SAVE_AU_B], SIGNAL(triggered()), this, SLOT( au_save_cb()));
	connect(fileMenuAct[FILE_QUIT_B], SIGNAL(triggered()), this, SLOT( quit_cb()));
	
	// Editj[FANVARlNV
	for( int num = 0; num < EDIT_B_NUM; num++ ) {
		editMenuAct[num] = new QAction(EDIT_SUBMENU_NAME[num], this);
	}
	connect(editMenuAct[EDIT_UNDO_B], SIGNAL(triggered()), this, SLOT( undo_cb()));
	connect(editMenuAct[EDIT_REDO_B], SIGNAL(triggered()), 	this, SLOT( redo_cb()));
	connect(editMenuAct[EDIT_RESET_ALL_B], SIGNAL(triggered()), 	this, SLOT( reset_all_cb()));
	connect(editMenuAct[EDIT_RESET_WINDOW_B], SIGNAL(triggered()), this, SLOT( reset_window_cb()));
	
	// Regionj[FANVARlNV
	for( int num = 0; num < REGION_B_NUM; num++ ) {
		regionMenuAct[num] = new QAction(REGION_SUBMENU_NAME[num], this);
	}
	connect(regionMenuAct[REGION_ANY_POINTS_B], SIGNAL(triggered()), this, SLOT( select_any_points_cb()));
	connect(regionMenuAct[REGION_WITH_AROUNT_B], SIGNAL(triggered()), this, SLOT( select_with_around_cb()));
	connect(regionMenuAct[REGION_HEAD_B], SIGNAL(triggered()), 	this, SLOT( select_head_cb()));
	connect(regionMenuAct[REGION_OUTLINE_B], SIGNAL(triggered()), this, SLOT( select_outline_cb()));
	connect(regionMenuAct[REGION_EYES_B], SIGNAL(triggered()), 	this, SLOT( select_eyes_cb()));
	connect(regionMenuAct[REGION_BROWS_B], SIGNAL(triggered()), this, SLOT( select_brows_cb()));
	connect(regionMenuAct[REGION_NOSE_B], SIGNAL(triggered()), this, SLOT( select_nose_cb()));
	connect(regionMenuAct[REGION_MOUTH_B], SIGNAL(triggered()), this, SLOT( select_mouth_cb()));
	connect(regionMenuAct[REGION_NECK_B], SIGNAL(triggered()), this, SLOT( select_neck_cb()));	
	
	regionMenuAct[REGION_ANY_POINTS_B]->setCheckable(true); regionMenuAct[REGION_ANY_POINTS_B]->setChecked(true);
	regionMenuAct[REGION_WITH_AROUNT_B]->setCheckable(true); regionMenuAct[REGION_WITH_AROUNT_B]->setChecked(false);
	regionMenuAct[REGION_HEAD_B]->setCheckable(true); regionMenuAct[REGION_HEAD_B]->setChecked(false);
	regionMenuAct[REGION_OUTLINE_B]->setCheckable(true); regionMenuAct[REGION_OUTLINE_B]->setChecked(false);
	regionMenuAct[REGION_EYES_B]->setCheckable(true); regionMenuAct[REGION_EYES_B]->setChecked(false);
	regionMenuAct[REGION_BROWS_B]->setCheckable(true); regionMenuAct[REGION_BROWS_B]->setChecked(false);
	regionMenuAct[REGION_NOSE_B]->setCheckable(true); regionMenuAct[REGION_NOSE_B]->setChecked(false);
	regionMenuAct[REGION_MOUTH_B]->setCheckable(true); regionMenuAct[REGION_MOUTH_B]->setChecked(false);
	regionMenuAct[REGION_NECK_B]->setCheckable(true); regionMenuAct[REGION_NECK_B]->setChecked(false);
	
	// Viewj[FANVARlNV
	for( int num = 0; num < VIEW_B_NUM; num++ ) {
		viewMenuAct[num] = new QAction(VIEW_SUBMENU_NAME[num], this);
	}
	connect(viewMenuAct[VIEW_EDITOR_B], SIGNAL(triggered()), this, SLOT( view_editor_cb()));
	connect(viewMenuAct[VIEW_EYE_B], SIGNAL(triggered()), this, SLOT( view_eye_cb()));
	connect(viewMenuAct[VIEW_TEETH_B], SIGNAL(triggered()), this, SLOT( view_teeth_cb()));
	connect(viewMenuAct[VIEW_AU_B], SIGNAL(triggered()), this, SLOT( view_au_cb()));
	connect(viewMenuAct[VIEW_COLOR_B], SIGNAL(triggered()), this, SLOT( view_color_cb()));
	
	viewMenuAct[VIEW_EDITOR_B]->setCheckable(true); viewMenuAct[VIEW_EDITOR_B]->setChecked(false);
	viewMenuAct[VIEW_EYE_B]->setCheckable(true); 	viewMenuAct[VIEW_EYE_B]->setChecked(false);
	viewMenuAct[VIEW_TEETH_B]->setCheckable(true);	viewMenuAct[VIEW_TEETH_B]->setChecked(false);
	viewMenuAct[VIEW_AU_B]->setCheckable(true);		viewMenuAct[VIEW_AU_B]->setChecked(false);

	
	// Helpj[FANVARlNV
	for( int num = 0; num < HELP_B_NUM; num++ ) {
		helpMenuAct[num] = new QAction(HELP_SUBMENU_NAME[num], this);
	}
	connect(helpMenuAct[HELP_SHORTCUT_B], SIGNAL(triggered()), this, SLOT( help_shortcut_cb()));
	connect(helpMenuAct[HELP_VERSION_B], SIGNAL(triggered()), this, SLOT( help_version_cb()));
	connect(helpMenuAct[HELP_QT_B], SIGNAL(triggered()), qApp, SLOT( aboutQt()));
	
	//    exitAct = new QAction(tr("E&xit"), this);
	//   exitAct->setShortcut(tr("Ctrl+Q"));
	//   connect(exitAct, SIGNAL(triggered()), this, SLOT(close()));

}

void MainWindow::createMenus()
{
	// gbvx̃j[
	for( int num = 0; num < MAIN_B_NUM; num++ ) {
		fmMenu[num] = menuBar()->addMenu(tr(MAIN_MENU_NAME[num]));
	}
	
	// Filej[
	for( int num = 0; num < FILE_B_NUM; num++ ) {
		fmMenu[MAIN_FILE_B]->addAction(fileMenuAct[num]);
	}
	// Editj[
	for( int num = 0; num < EDIT_B_NUM; num++ ) {
		fmMenu[MAIN_EDIT_B]->addAction(editMenuAct[num]);
	}
	// Regionj[
	for( int num = 0; num < REGION_B_NUM; num++ ) {
		fmMenu[MAIN_REGION_B]->addAction(regionMenuAct[num]);
	}
	// Viewj[
	for( int num = 0; num < VIEW_B_NUM; num++ ) {
		fmMenu[MAIN_VIEW_B]->addAction(viewMenuAct[num]);
	}
	// Helpj[
	for( int num = 0; num < HELP_B_NUM; num++ ) {
		fmMenu[MAIN_HELP_B]->addAction(helpMenuAct[num]);
	}
	
	
	//    fileMenu->addAction(renderIntoPixmapAct);
	//    fileMenu->addAction(grabFrameBufferAct);
	//    fileMenu->addAction(clearPixmapAct);
	//    fileMenu->addSeparator();
	//    fileMenu->addAction(exitAct);
	
	//	editMenu = menuBar()->addMenu(tr("&File"));
	//	regionMenu = menuBar()->addMenu(tr("&Region"));
	//	viewMenu = menuBar()->addMenu(tr("&View"));

}
// file
void MainWindow::clear_file_cb() 
{
	int ret = QMessageBox::information(this, tr("Information"), 
									   tr("Do you want to create new face model?"),
									   QMessageBox::Yes | QMessageBox::Default, QMessageBox::No);
	if( ret == QMessageBox::Yes ) {
		m_pDocument->FileClear();
		ButtonStatusNewImage();
	}
}
void MainWindow::open_face_cb() 
{
	QString fileName = QFileDialog::getOpenFileName(this, tr("Open Face Image"), 
													"../sample/", tr("Image files (*.bmp *.rgb)"));
	if(!fileName.isEmpty()) {
		if( m_pDocument->ImageOpen(fileName.toStdString().c_str()) == false ) {
			QMessageBox::warning(this, tr("Error"), tr("Cannot open face image file."), 
								 QMessageBox::Yes | QMessageBox::Default);
		}
		else {
			ButtonStatusFileOpen();
		}
	}
}
void MainWindow::open_pnt_cb() 
{
	QString fileName = QFileDialog::getOpenFileName(this, tr("Open Face Model File"), 
													"../sample/", tr("Face model files (*.pnt)"));
	if(!fileName.isEmpty()) {
		if( m_pDocument->PntOpen(fileName.toStdString().c_str()) == false ) {
			QMessageBox::warning(this, tr("Error"), tr("Cannot open face model file."), 
								 QMessageBox::Yes | QMessageBox::Default);
		}
		else {
			m_pDialogEdit->SetRenewalInfo();
			ButtonStatusPntOpen();
		}
	}
}
void MainWindow::save_pnt_cb() 
{
	QFileDialog saveDialog;	
	QString fileName = saveDialog.getSaveFileName(this, tr("Save Face Model File"), 
												  "../sample/", tr("Face model files (*.pnt)"));
	if(!fileName.isEmpty()) {
		Wfm *wfm = m_pDocument->GetWorkWfm();
		wfm->save(fileName.toStdString().c_str());
	}
}
void MainWindow::eye_tex_open_cb() 
{
	QString fileName = QFileDialog::getOpenFileName(this, tr("Open Eye Image File"), 
													"../sample/", tr("Image files (*.bmp *.sgi)"));
	if(!fileName.isEmpty()) {
		if( m_pDocument->EyeTextureOpen(fileName.toStdString().c_str()) == false ) {
			QMessageBox::warning(this, tr("Error"), tr("Cannot open eye image file."), 
								 QMessageBox::Yes | QMessageBox::Default);
		}
		else {
			ObjModel *obj = m_pDocument->GetEyeObject();
			obj->ReCalcTexture(m_pDocument->GetEyeTexScale());
			m_pDialogEdit->SetRecreateEyeCallList();
		}
	}
	editGLDlg->redraw_window();
}

void MainWindow::eye_open_cb() 
{ 
	QString fileName = QFileDialog::getOpenFileName(this, tr("Open Eye Definition File"), 
													"../sample/", tr("Eye definition file (*.def_e)"));
	if(!fileName.isEmpty()) {
		if( m_pDocument->EyeFileOpen(fileName.toStdString().c_str()) == false ) {
			QMessageBox::warning(this, tr("Error"), tr("Cannot open eye definition file."), 
								 QMessageBox::Yes | QMessageBox::Default);
		}
		else {
			ObjModel *obj = m_pDocument->GetEyeObject();
			obj->ReCalcTexture(m_pDocument->GetEyeTexScale());
			m_pDialogEdit->SetRecreateEyeCallList();
			eyeDlg->SetTransSliderValue(EyeDlg::EYE_SLIDER_TRANS_Z_LEFT, m_pDocument->GetEyeLLocalTrans()[2]);
			eyeDlg->SetTransSliderValue(EyeDlg::EYE_SLIDER_TRANS_Z_RIGHT, m_pDocument->GetEyeRLocalTrans()[2]);
			eyeDlg->SetRotateSliderValue(EyeDlg::EYE_SLIDER_ROT_X_LEFT, m_pDocument->GetEyeLLocalRot()[0]);
			eyeDlg->SetRotateSliderValue(EyeDlg::EYE_SLIDER_ROT_X_RIGHT, m_pDocument->GetEyeRLocalRot()[0]);
			eyeDlg->SetRotateSliderValue(EyeDlg::EYE_SLIDER_ROT_Y_LEFT, m_pDocument->GetEyeLLocalRot()[1]);
			eyeDlg->SetRotateSliderValue(EyeDlg::EYE_SLIDER_ROT_Y_RIGHT, m_pDocument->GetEyeRLocalRot()[1]);
			eyeDlg->SetScaleSliderValue(EyeDlg::EYE_SLIDER_SCALE, m_pDocument->GetEyeTexScale());
		}
	}
	editGLDlg->redraw_window();
}
void MainWindow::eye_save_cb()
{
	QFileDialog saveDialog;	
	QString fileName = saveDialog.getSaveFileName(this, tr("Save Eye Definition File"), 
												  "../sample/", tr("Eye definition file (*.def_e)"));
	if(!fileName.isEmpty()) {
		m_pDocument->EyeFileSave(fileName.toStdString().c_str());
	}
}
void MainWindow::teeth_open_cb()
{
	QString fileName = QFileDialog::getOpenFileName(this, tr("Open Teeth Definition File"), 
													"../sample/", tr("Teeth definition file (*.def_t)"));
	if(!fileName.isEmpty()) {
		if( m_pDocument->TeethFileOpen(fileName.toStdString().c_str()) == false ) {
			QMessageBox::warning(this, tr("Error"), tr("Cannot open teeth definition file."), 
								 QMessageBox::Yes | QMessageBox::Default);
		}
		else {
			teethDlg->SetSliderValue(TeethDlg::TEETH_SLIDER_DIF_RED, m_pDocument->GetTeethDifColor()[0]);
			teethDlg->SetSliderValue(TeethDlg::TEETH_SLIDER_DIF_BLUE, m_pDocument->GetTeethDifColor()[1]);
			teethDlg->SetSliderValue(TeethDlg::TEETH_SLIDER_DIF_GREEN, m_pDocument->GetTeethDifColor()[2]);
		}
	}
	editGLDlg->redraw_window();
}
void MainWindow::teeth_save_cb()
{
	QFileDialog saveDialog;	
	QString fileName = saveDialog.getSaveFileName(this, tr("Save Teeth Definition File"), 
												  "../sample/", tr("Eye definition file (*.def_t)"));
	if(!fileName.isEmpty()) {
		m_pDocument->TeethFileSave(fileName.toStdString().c_str());
	}
}
void MainWindow::au_open_cb()
{
	QString fileName = QFileDialog::getOpenFileName(this, tr("Open AU File"), 
													"../sample/", tr("AU file (*.pnt)"));
	if(!fileName.isEmpty()) {
		if(auDlg->OpenUserAU(fileName.toStdString().c_str()) == false ) {
			QMessageBox::warning(this, tr("Error"), tr("Cannot open AU file."), 
								 QMessageBox::Yes | QMessageBox::Default);
		}
	}
	editGLDlg->redraw_window();
}
void MainWindow::au_save_cb()
{
	QFileDialog saveDialog;	
	QString fileName = saveDialog.getSaveFileName(this, tr("Save AU File"), 
												  "../sample/", tr("AU file (*.pnt)"));
	if(!fileName.isEmpty()) {
		if(auDlg->SaveUserAU(fileName.toStdString().c_str()) == false ) {
			QMessageBox::warning(this, tr("Error"), tr("Cannot save AU file."), 
								 QMessageBox::Yes | QMessageBox::Default);
		}
	}
}
void MainWindow::quit_cb()
{
	int ret = QMessageBox::information(this, tr("Information"), 
									   tr("Do you want to close the window?"),
									   QMessageBox::Yes | QMessageBox::Default, QMessageBox::No);
	if( ret == QMessageBox::Yes ) {
		close();
	}
}

void MainWindow::view_editor_cb()
{
	if( editGLDlg->isVisible() ) {
		editGLDlg->hide();
		viewMenuAct[VIEW_EDITOR_B]->setChecked(false);
	}
	else {
		editGLDlg->show();
		editGLDlg->raise();
		viewMenuAct[VIEW_EDITOR_B]->setChecked(true);
	}
}
void MainWindow::view_au_cb()
{
	if( auDlg->isVisible() ) {
		auDlg->hide();
		viewMenuAct[VIEW_AU_B]->setChecked(false);
	}
	else {
		auDlg->show();
		auDlg->raise();
		viewMenuAct[VIEW_AU_B]->setChecked(true);
	}
}
void MainWindow::view_teeth_cb()
{
	if( teethDlg->isVisible() ) {
		teethDlg->hide();
		viewMenuAct[VIEW_TEETH_B]->setChecked(false);
	}
	else {
		teethDlg->show();
		teethDlg->raise();
		viewMenuAct[VIEW_TEETH_B]->setChecked(true);
	}	
}
void MainWindow::view_eye_cb()
{
	if( eyeDlg->isVisible() ) {
		eyeDlg->hide();
		viewMenuAct[VIEW_EYE_B]->setChecked(false);
	}
	else {
		eyeDlg->show();
		eyeDlg->raise();
		viewMenuAct[VIEW_EYE_B]->setChecked(true);
	}	
}

void MainWindow::view_color_cb()
{
	m_pView->HiperColor();
}

void MainWindow::help_shortcut_cb()
{
 	QMessageBox::about(this, tr("About Shortcut"), 
					   tr("Shortcut keys:\n"
						  "[ctrl + n] New edit\n"
						  "[ctrl + o] Open face image\n"
						  "[ctrl + p] Open Wireframe model [pnt]\n"
						  "[ctrl + s] Save Wireframe model [pnt]\n"
						  "[ctrl + z] Undo\n"
						  "[ctrl + y] Redo\n"
						  "[ctrl + r] Reset model and texture position\n"
						  "[1] Region select: any points\n"
						  "[2] Region select: with around\n"
						  "[3] Region select: head\n"
						  "[4] Region select: outline\n"
						  "[5] Region select: eyes\n"
						  "[6] Region select: brows\n"
						  "[7] Region select: nose\n"
						  "[8] Region select: mouth\n"
						  "[9] Region select: neck\n"));
}
void MainWindow::help_version_cb()
{
    QMessageBox::about(this, tr("About FaceMaker"), tr(VERSIONINFO));
}
// region
void MainWindow::select_any_points_cb()
{
	m_pView->SetEditRegion(REGION_BIT_ANYPOINTS);
	m_pView->SetFittingMode(TRANS_ALL);
	uncheckSelect();
	regionMenuAct[REGION_ANY_POINTS_B]->setChecked(true);
}
void MainWindow::select_with_around_cb()
{
	m_pView->SetEditRegion(REGION_BIT_WITHAROUND);
	m_pView->SetFittingMode(TRANS_WITHAROUND);
	uncheckSelect();
	regionMenuAct[REGION_WITH_AROUNT_B]->setChecked(true);
}
void MainWindow::select_head_cb()
{
	m_pView->SetEditRegion(REGION_BIT_HEAD);
	m_pView->SetFittingMode(TRANS_HEAD);
	uncheckSelect();
	regionMenuAct[REGION_HEAD_B]->setChecked(true);
}
void MainWindow::select_outline_cb()
{
	m_pView->SetEditRegion(REGION_BIT_OUTLINE);
	m_pView->SetFittingMode(TRANS_CONTOUR);
	uncheckSelect();
	regionMenuAct[REGION_OUTLINE_B]->setChecked(true);
}
void MainWindow::select_eyes_cb()
{
	m_pView->SetEditRegion(REGION_BIT_EYES);
	m_pView->SetFittingMode(TRANS_EYE);
	uncheckSelect();
	regionMenuAct[REGION_EYES_B]->setChecked(true);
}
void MainWindow::select_brows_cb()
{
	m_pView->SetEditRegion(REGION_BIT_BROWS);
	m_pView->SetFittingMode(TRANS_BROW);
	uncheckSelect();
	regionMenuAct[REGION_BROWS_B]->setChecked(true);
}
void MainWindow::select_nose_cb()
{
	m_pView->SetEditRegion(REGION_BIT_NOSE);
	m_pView->SetFittingMode(TRANS_NOSE);
	uncheckSelect();
	regionMenuAct[REGION_NOSE_B]->setChecked(true);
}
void MainWindow::select_mouth_cb()
{
	m_pView->SetEditRegion(REGION_BIT_MOUTH);
	m_pView->SetFittingMode(TRANS_MOUTH);
	uncheckSelect();
	regionMenuAct[REGION_MOUTH_B]->setChecked(true);
}
void MainWindow::select_neck_cb()
{
	m_pView->SetEditRegion(REGION_BIT_NECK);
	m_pView->SetFittingMode(TRANS_NECK);
	uncheckSelect();
	regionMenuAct[REGION_NECK_B]->setChecked(true);	
}	
void MainWindow::uncheckSelect()
{
	regionMenuAct[REGION_ANY_POINTS_B]->setChecked(false);
	regionMenuAct[REGION_WITH_AROUNT_B]->setChecked(false);
	regionMenuAct[REGION_HEAD_B]->setChecked(false);
	regionMenuAct[REGION_OUTLINE_B]->setChecked(false);
	regionMenuAct[REGION_EYES_B]->setChecked(false);
	regionMenuAct[REGION_BROWS_B]->setChecked(false);
	regionMenuAct[REGION_NOSE_B]->setChecked(false);
	regionMenuAct[REGION_MOUTH_B]->setChecked(false);
	regionMenuAct[REGION_NECK_B]->setChecked(false);	
	
}

// edit
void MainWindow::undo_cb()
{
	m_pView->EditUndo();
}
void MainWindow::redo_cb()
{
	m_pView->EditRedo();
}
void MainWindow::reset_all_cb()
{
	m_pView->SetLocalTranslate( 0, 0.0 );
	m_pView->SetLocalTranslate( 1, 0.0 );
	m_pView->SetLocalTranslate( 2, 0.0 );
	m_pView->SetLocalRotate( 0, 0.0 );
	m_pView->SetLocalRotate( 1, 0.0 );
	m_pView->SetLocalRotate( 2, 0.0 );
	m_pView->SetLocalScale( 1.0 );	
}
void MainWindow::reset_window_cb()
{
	if(m_pDocument->GetTexture()) {
		int x_size = m_pDocument->GetTexture()->GetWidth();
		int y_size = m_pDocument->GetTexture()->GetHeight();
		m_pView->RenewalDocument();
		m_main_window_size[0] = x_size;
		m_main_window_size[1] = y_size;
		resize(m_main_window_size[0], m_main_window_size[1]);
	}
	else {
		m_pView->RenewalDocument();
		m_main_window_size[0] = MAIN_WIDTH;
		m_main_window_size[1] = MAIN_HEIGHT;
		resize(m_main_window_size[0], m_main_window_size[1]);

	}
}
void MainWindow::ButtonStatusNewImage()
{
	fileMenuAct[FILE_NEW_EDIT_B]->setEnabled(false);
	fileMenuAct[FILE_OPEN_FACE_IMAGE_B]->setEnabled(true);
	fileMenuAct[FILE_OPEN_PNT_B]->setEnabled(false);
	fileMenuAct[FILE_SAVE_PNT_B]->setEnabled(false);
	fileMenuAct[FILE_OPEN_EYE_TEX]->setEnabled(false);
	fileMenuAct[FILE_OPEN_EYE_B]->setEnabled(false);
	fileMenuAct[FILE_SAVE_EYE_B]->setEnabled(false);
	fileMenuAct[FILE_OPEN_TEETH_B]->setEnabled(false);
	fileMenuAct[FILE_SAVE_TEETH_B]->setEnabled(false);
	fileMenuAct[FILE_OPEN_AU_B]->setEnabled(false);
	fileMenuAct[FILE_SAVE_AU_B]->setEnabled(false);
	fileMenuAct[FILE_QUIT_B]->setEnabled(true);
	
	editMenuAct[EDIT_UNDO_B]->setEnabled(false);
	editMenuAct[EDIT_REDO_B]->setEnabled(false);
	editMenuAct[EDIT_RESET_ALL_B]->setEnabled(false);
	editMenuAct[EDIT_RESET_WINDOW_B]->setEnabled(false);

	regionMenuAct[REGION_ANY_POINTS_B]->setEnabled(false);
	regionMenuAct[REGION_WITH_AROUNT_B]->setEnabled(false);
	regionMenuAct[REGION_HEAD_B]->setEnabled(false);
	regionMenuAct[REGION_OUTLINE_B]->setEnabled(false);
	regionMenuAct[REGION_EYES_B]->setEnabled(false);
	regionMenuAct[REGION_BROWS_B]->setEnabled(false);
	regionMenuAct[REGION_NOSE_B]->setEnabled(false);
	regionMenuAct[REGION_MOUTH_B]->setEnabled(false);
	regionMenuAct[REGION_NECK_B]->setEnabled(false);

	viewMenuAct[VIEW_EDITOR_B]->setEnabled(false);
	viewMenuAct[VIEW_EYE_B]->setEnabled(false);
	viewMenuAct[VIEW_TEETH_B]->setEnabled(false);
	viewMenuAct[VIEW_AU_B]->setEnabled(false);
	viewMenuAct[VIEW_COLOR_B]->setEnabled(false);
}
void MainWindow::ButtonStatusFileOpen()
{
	fileMenuAct[FILE_NEW_EDIT_B]->setEnabled(true);
	fileMenuAct[FILE_OPEN_FACE_IMAGE_B]->setEnabled(false);
	fileMenuAct[FILE_OPEN_PNT_B]->setEnabled(true);
	fileMenuAct[FILE_SAVE_PNT_B]->setEnabled(false);
	fileMenuAct[FILE_OPEN_EYE_TEX]->setEnabled(false);
	fileMenuAct[FILE_OPEN_EYE_B]->setEnabled(false);
	fileMenuAct[FILE_SAVE_EYE_B]->setEnabled(false);
	fileMenuAct[FILE_OPEN_TEETH_B]->setEnabled(false);
	fileMenuAct[FILE_SAVE_TEETH_B]->setEnabled(false);
	fileMenuAct[FILE_OPEN_AU_B]->setEnabled(false);
	fileMenuAct[FILE_SAVE_AU_B]->setEnabled(false);
	fileMenuAct[FILE_QUIT_B]->setEnabled(true);
	
	editMenuAct[EDIT_UNDO_B]->setEnabled(false);
	editMenuAct[EDIT_REDO_B]->setEnabled(false);
	editMenuAct[EDIT_RESET_ALL_B]->setEnabled(false);
	editMenuAct[EDIT_RESET_WINDOW_B]->setEnabled(false);

	regionMenuAct[REGION_ANY_POINTS_B]->setEnabled(false);
	regionMenuAct[REGION_WITH_AROUNT_B]->setEnabled(false);
	regionMenuAct[REGION_HEAD_B]->setEnabled(false);
	regionMenuAct[REGION_OUTLINE_B]->setEnabled(false);
	regionMenuAct[REGION_EYES_B]->setEnabled(false);
	regionMenuAct[REGION_BROWS_B]->setEnabled(false);
	regionMenuAct[REGION_NOSE_B]->setEnabled(false);
	regionMenuAct[REGION_MOUTH_B]->setEnabled(false);
	regionMenuAct[REGION_NECK_B]->setEnabled(false);

	viewMenuAct[VIEW_EDITOR_B]->setEnabled(false);
	viewMenuAct[VIEW_EYE_B]->setEnabled(false);
	viewMenuAct[VIEW_TEETH_B]->setEnabled(false);
	viewMenuAct[VIEW_AU_B]->setEnabled(false);
	viewMenuAct[VIEW_COLOR_B]->setEnabled(false);
}

void MainWindow::ButtonStatusPntOpen()
{
	fileMenuAct[FILE_NEW_EDIT_B]->setEnabled(true);
	fileMenuAct[FILE_OPEN_FACE_IMAGE_B]->setEnabled(false);
	fileMenuAct[FILE_OPEN_PNT_B]->setEnabled(false);
	fileMenuAct[FILE_SAVE_PNT_B]->setEnabled(true);
	fileMenuAct[FILE_OPEN_EYE_TEX]->setEnabled(true);
	fileMenuAct[FILE_OPEN_EYE_B]->setEnabled(true);
	fileMenuAct[FILE_SAVE_EYE_B]->setEnabled(true);
	fileMenuAct[FILE_OPEN_TEETH_B]->setEnabled(true);
	fileMenuAct[FILE_SAVE_TEETH_B]->setEnabled(true);
	fileMenuAct[FILE_OPEN_AU_B]->setEnabled(true);
	fileMenuAct[FILE_SAVE_AU_B]->setEnabled(true);
	fileMenuAct[FILE_QUIT_B]->setEnabled(true);
	
	editMenuAct[EDIT_UNDO_B]->setEnabled(true);
	editMenuAct[EDIT_REDO_B]->setEnabled(true);
	editMenuAct[EDIT_RESET_ALL_B]->setEnabled(true);
	editMenuAct[EDIT_RESET_WINDOW_B]->setEnabled(true);

	regionMenuAct[REGION_ANY_POINTS_B]->setEnabled(true);
	regionMenuAct[REGION_WITH_AROUNT_B]->setEnabled(true);
	regionMenuAct[REGION_HEAD_B]->setEnabled(true);
	regionMenuAct[REGION_OUTLINE_B]->setEnabled(true);
	regionMenuAct[REGION_EYES_B]->setEnabled(true);
	regionMenuAct[REGION_BROWS_B]->setEnabled(true);
	regionMenuAct[REGION_NOSE_B]->setEnabled(true);
	regionMenuAct[REGION_MOUTH_B]->setEnabled(true);
	regionMenuAct[REGION_NECK_B]->setEnabled(true);

	viewMenuAct[VIEW_EDITOR_B]->setEnabled(true);
	viewMenuAct[VIEW_EYE_B]->setEnabled(true);
	viewMenuAct[VIEW_TEETH_B]->setEnabled(true);
	viewMenuAct[VIEW_AU_B]->setEnabled(true);
	viewMenuAct[VIEW_COLOR_B]->setEnabled(true);
}
