#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QMainWindow>
#include "Resource.h"

class QAction;
class QLabel;
class QMenu;
class QScrollArea;
class QSlider;
class GLWidget;
class EditGLDlg;
class AuDlg;
class TeethDlg;
class EyeDlg;

class Document;
class View;
class DialogEdit;

class MainWindow : public QMainWindow
{
	Q_OBJECT

		public:
		MainWindow();

private slots:
	// file	
	void clear_file_cb();
	void open_face_cb();
	void open_pnt_cb();
	void save_pnt_cb();
	void eye_tex_open_cb();
	void eye_open_cb();
	void eye_save_cb();
	void teeth_open_cb();
	void teeth_save_cb();
	void au_open_cb();
	void au_save_cb();
	void quit_cb();
	
	// edit
	void undo_cb(); 
	void redo_cb(); 
	void reset_all_cb(); 
	void reset_window_cb();	

	// region
	void select_any_points_cb();
	void select_with_around_cb();
	void select_head_cb();
	void select_outline_cb();
	void select_eyes_cb();
	void select_brows_cb(); 
	void select_nose_cb(); 
	void select_mouth_cb(); 
	void select_neck_cb(); 
	
	// view
	void view_editor_cb();
	void view_eye_cb();
	void view_teeth_cb();
	void view_au_cb();
	void view_color_cb(); 
	
	// help
	void help_shortcut_cb();
	void help_version_cb();
	

private:
    void createActions();
    void createMenus();
    QSize getSize();

	void uncheckSelect();
	
	// button status
	void ButtonStatusFileOpen();
	void ButtonStatusNewImage();
	void ButtonStatusPntOpen();
	
    QWidget *centralWidget;
    QScrollArea *glWidgetArea;
    GLWidget *glWidget;
	EditGLDlg *editGLDlg;
	AuDlg *auDlg;
	TeethDlg *teethDlg;
	EyeDlg *eyeDlg;
	
	QMenu *fmMenu[MAIN_B_NUM];
	
	QAction *fileMenuAct[FILE_B_NUM];
	QAction *editMenuAct[EDIT_B_NUM];
	QAction *regionMenuAct[REGION_B_NUM];
	QAction *viewMenuAct[VIEW_B_NUM];
	QAction *helpMenuAct[HELP_B_NUM];
	
	// FaceMaker
	Document *m_pDocument;
	View *m_pView;
	DialogEdit *m_pDialogEdit;
	
	int m_main_window_size[2];
	int m_edit_window_size[2];
	
};

#endif
