#include <QtGui>

#include "teethDlg.h"

#define MAX_SCALE_TEETH 255
#define MIN_SCALE_TEETH 0
#define UNIT_TEETH 1.0/255.0

TeethDlg::TeethDlg(EditGLDlg *editGLDlg, QWidget *parent)
	: QDialog(parent)
{
	m_pEditGLDlg = editGLDlg;
	
	for( int num = 0; num < TEETH_SLIDER_NUM; num++ ) {
		m_pLabel[num] = new QLabel(tr(TEETH_SLIDER_NAME[num]));
		m_pLabel[num]->setAlignment(Qt::AlignRight);
		m_pSpin[num] = new QSpinBox;
		m_pSpin[num]->setRange(MIN_SCALE_TEETH, MAX_SCALE_TEETH);
		m_pSlider[num] = new QSlider(Qt::Horizontal);
		m_pSlider[num]->setRange(MIN_SCALE_TEETH, MAX_SCALE_TEETH);
			
		QObject::connect(m_pSpin[num], SIGNAL(valueChanged(int)),
						 m_pSlider[num], SLOT(setValue(int)));
		QObject::connect(m_pSlider[num], SIGNAL(valueChanged(int)),
						 m_pSpin[num], SLOT(setValue(int)));
		QObject::connect(m_pSpin[num], SIGNAL(valueChanged(int)),
						 this, SLOT(TeethChange()));
		m_pSpin[num]->setValue(MAX_SCALE_TEETH);
	}
	
	QGridLayout *layout = new QGridLayout;
	layout->setSpacing(1);

	int num;
	for( num = 0; num < TEETH_SLIDER_NUM; num++ ) {
		layout->addWidget(m_pLabel[num], num, 0);
		layout->addWidget(m_pSpin[num],  num, 1);
		layout->addWidget(m_pSlider[num],num, 2);
	}	
  	setLayout(layout);
	
	setWindowTitle(tr("Teeth Color Controller"));
}

void TeethDlg::SetSliderValue(int num, float value)
{
	m_pSpin[num]->setValue(int(value / UNIT_TEETH));
}

void TeethDlg::TeethChange()
{
	float *dTeethValue = m_pEditGLDlg->GetDocument()->GetTeethDifColor();
	
	for( int i = 0; i < TEETH_SLIDER_NUM; i++ ) {
		dTeethValue[i] = m_pSpin[i]->value() * UNIT_TEETH;
	}
	
	m_pEditGLDlg->redraw_window();
}

const char *TeethDlg::TEETH_SLIDER_NAME[] =
{
	"Red",
	"Green",
	"Blue",
	NULL
};

